experimental_lowqa.tasks.yambs.jlink package — docs

Skip to main content
`Ctrl`+`K`

# experimental_lowqa.tasks.yambs.jlink package

## Submodules

## experimental_lowqa.tasks.yambs.jlink.gdbserver module

A module for working with J-Link GDBServer.

experimental_lowqa.tasks.yambs.jlink.gdbserver.jlink_gdbserver_task(board: str, third_party: Path, name: str = None) → JlinkTask

  Create a JLink GDB server task.

## Module contents

A module for project-specific SEGGER J-Link tasks.

class experimental_lowqa.tasks.yambs.jlink.JlinkExtract(name: str, *args, execute: Callable[[dict[str, dict[str, Any]], dict[str, Any]], Coroutine[Any, Any, bool]] = None, log: Logger = None, timer: Timer = None, target: Target = None, **kwargs)

  Bases: `SubprocessLogMixin`

  A class for extracting J-Link software.

  async run(inbox: dict[str, dict[str, Any]], outbox: dict[str, Any], *args, **kwargs) → bool

    Run the task.

class experimental_lowqa.tasks.yambs.jlink.JlinkTask(name: str, *args, execute: Callable[[dict[str, dict[str, Any]], dict[str, Any]], Coroutine[Any, Any, bool]] = None, log: Logger = None, timer: Timer = None, target: Target = None, **kwargs)

  Bases: `SubprocessLogMixin`

  A class for running J-Link software.

  default_requirements: set[str] = {'extract-jlink', 'vmklib.init'}
  async run(inbox: dict[str, dict[str, Any]], outbox: dict[str, Any], *args, **kwargs) → bool

    Run the task.

experimental_lowqa.tasks.yambs.jlink.find_jlink_dir(path: Path) → Path | None

  Find the JLink extracted software directory.

experimental_lowqa.tasks.yambs.jlink.register_jlink(manager: TaskManager, third_party: Path) → bool

  Register SEGGER JLink-related tasks.